@@ -56,10 +56,14 @@ using namespace std;
 
 #include "fsq_varicode.cxx"
 
+void  clear_xmt_arrays();
+
 static int symlen = 4096; // nominal symbol length; 3 baud
 #define SQLFILT_SIZE 200
 #define NIT std::string::npos
 
+#define txcenterfreq  1500.0
+
 static const char *FSQBOL = " \n";
 static const char *FSQEOL = "\n ";
 static const char *FSQEOT = "  \b  ";
@@ -138,7 +142,7 @@ void printit(double speed, int bandwidth, int symlen, int bksize, int peak_hits,
 
 fsq::fsq(trx_mode md) : modem()
 {
-	modem::set_freq(1500);
+	modem::set_freq(1500); // default Rx/Tx center frequency
 
 	mode = md;
 	samplerate = SR;
@@ -215,7 +219,6 @@ fsq::~fsq()
 
 void  fsq::tx_init(SoundBase *sc)
 {
-	set_freq(1500);
 	scard = sc;
 	tone = prevtone = 0;
 	txphase = 0;
@@ -228,7 +231,7 @@ void  fsq::tx_init(SoundBase *sc)
 
 void  fsq::rx_init()
 {
-	set_freq(1500);
+	set_freq(frequency);
 	bandwidth = 33 * spacing * samplerate / FSQ_SYMLEN;
 	bkptr = 0;
 	peak_counter = 0;
@@ -262,10 +265,13 @@ void fsq::init()
 
 void fsq::set_freq(double f)
 {
-	frequency = 1500; modem::set_freq(frequency);
+	frequency = f;
+	modem::set_freq(frequency);
 	basetone = ceil(1.0*(frequency - bandwidth / 2) * FSQ_SYMLEN / samplerate);
+	tx_basetone = ceil((get_txfreq() - bandwidth / 2) * FSQ_SYMLEN / samplerate );
 	int incr = basetone % spacing;
 	basetone -= incr;
+	tx_basetone -= incr;
 }
 
 void fsq::show_mode()
@@ -298,10 +304,7 @@ void fsq::adjust_for_speed()
 
 void fsq::restart()
 {
-	modem::set_freq(1500);
-	basetone = ceil(1.0*(frequency - bandwidth / 2) * FSQ_SYMLEN / samplerate);
-	int incr = basetone % spacing;
-	basetone -= incr;
+	set_freq(frequency);
 
 	peak_hits = progdefaults.fsqhits;
 	adjust_for_speed();
@@ -344,21 +347,28 @@ static string cqcqcq = "cqcqcq";
 
 static fre_t call("([[:alnum:]]?[[:alpha:]/]+[[:digit:]]+[[:alnum:]/]+)", REG_EXTENDED);
 
-bool fsq::valid_callsign(std::string s)
-{
-	if (s.length() < 3) return false;
-	if (s.length() > 20) return false;
-//	if (s.find(' ') != std::string::npos) return false;
+// test for valid callsign
+// returns:
+// 0 - not a callsign
+// 1 - mycall
+// 2 - allcall
+// 4 - cqcqcq
+// 8 - any other valid call
 
-	if (s == allcall) return true;
-	if (s == cqcqcq) return true;
-	if (s == mycall) return true;
+int fsq::valid_callsign(std::string s)
+{
+	if (s.length() < 3) return 0;
+	if (s.length() > 20) return 0;
+
+	if (s == allcall) return 2;
+	if (s == cqcqcq) return 4;
+	if (s == mycall) return 1;
 
 	static char sz[21];
 	memset(sz, 0, 21);
 	strcpy(sz, s.c_str());
 	bool matches = call.match(sz);
-	return matches;
+	return (matches ? 8 : 0);
 }
 
 void fsq::parse_rx_text()
@@ -431,22 +441,47 @@ void fsq::parse_rx_text()
 	bool all = false;
 	bool directed = false;
 
-	p = 0;
+// test next word in string
+	size_t tr_pos = 0;
+	char tr = rx_text[tr_pos];
+	size_t trigger = triggers.find(tr);
+// strip any leading spaces before either text or first directed callsign
+	while (rx_text.length() > 1 &&
+		triggers.find(rx_text[0]) != std::string::npos)
+		rx_text.erase(0,1);
+// find first word
+	while ( tr_pos < rx_text.length()
+			&& ((trigger = triggers.find(rx_text[tr_pos])) == std::string::npos) ) {
+		tr_pos++;
+	}
 
-	if (rx_text.find(allcall) == 0) {
-		all = true;
-		rx_text.erase(0, 7);
-	}
-	else if (rx_text.find(cqcqcq) == 0) {
-		all = true;
-		rx_text.erase(0,6);
-	}
-// this next test does not allow for :othercall mycall othercallT where T is trigger
-// only :mycallT
-// but it does provide for the MONITOR of the transmission in next test
-	else if (rx_text.find(mycall) == 0) {
-		directed = true;
-		rx_text.erase(0, mycall.length());
+	while (trigger != std::string::npos && tr_pos < rx_text.length()) {
+		int word_is = valid_callsign(rx_text.substr(0, tr_pos));
+
+		if (word_is == 0) {
+			rx_text.insert(0," ");
+			break; // not a callsign
+		}
+		if (word_is == 1) directed = true; // mycall
+		// test for cqcqcq and allcall
+		else if (word_is != 8) all = true;
+
+		rx_text.erase(0, tr_pos);
+		if (rx_text[0] != ' ') break;
+
+		while (rx_text.length() > 1 &&
+			(rx_text[0] == ' ' && rx_text[1] == ' '))
+			rx_text.erase(0,1);
+
+		rx_text.erase(0, 1);
+		tr_pos = 0;
+		tr = rx_text[tr_pos];
+		trigger = triggers.find(tr);
+		while ( tr_pos < rx_text.length() && (trigger == std::string::npos) ) {
+			tr_pos++;
+			tr = rx_text[tr_pos];
+			trigger = triggers.find(tr);
+		}
 	}
 
 	if ( (all == false) && (directed == false)) {
@@ -454,14 +489,14 @@ void fsq::parse_rx_text()
 		return;
 	}
 
-// remove eot
-	rx_text.erase(rx_text.length() - 3);
+// remove eot if present
+	if (rx_text.length() > 3) rx_text.erase(rx_text.length() - 3);
 
 	toprint.assign(station_calling).append(":");
 
 // test for trigger
-	char tr = rx_text[0];
-	size_t trigger = triggers.find(tr);
+	tr = rx_text[0];
+	trigger = triggers.find(tr);
 
 	if (trigger == NIT) {
 		tr = ' '; // force to be text line
@@ -476,38 +511,38 @@ void fsq::parse_rx_text()
 		return;
 	}
 
+// now process own call triggers
+	if (directed) {
+		switch (tr) {
+			case ' ': parse_space(false);   break;
+			case '?': parse_qmark();   break;
+			case '*': parse_star();    break;
+			case '+': parse_plus();    break;
+			case '-': break;//parse_minus();   break;
+			case ';': parse_relay();    break;
+			case '!': parse_repeat();    break;
+			case '~': parse_delayed_repeat();   break;
+			case '#': parse_pound();   break;
+			case '$': parse_dollar();  break;
+			case '@': parse_at();      break;
+			case '&': parse_amp();     break;
+			case '^': parse_carat();   break;
+			case '%': parse_pcnt();    break;
+			case '|': parse_vline();   break;
+			case '>': parse_greater(); break;
+			case '<': parse_less();    break;
+			case '[': parse_relayed(); break;
+		}
+	}
+
 // if allcall; only respond to the ' ', '*', '#', and '%' triggers
-	if (all) {
+	else {
 		switch (tr) {
 			case ' ': parse_space(true);   break;
 			case '*': parse_star();    break;
 			case '#': parse_pound();   break;
 			case '%': parse_pcnt();    break;
 		}
-		rx_text.clear();
-		return;
-	}
-
-// now process own call triggers
-	switch (tr) {
-		case ' ': parse_space(false);   break;
-		case '?': parse_qmark();   break;
-		case '*': parse_star();    break;
-		case '+': parse_plus();    break;
-		case '-': break;//parse_minus();   break;
-		case ';': parse_relay();    break;
-		case '!': parse_repeat();    break;
-		case '~': parse_delayed_repeat();   break;
-		case '#': parse_pound();   break;
-		case '$': parse_dollar();  break;
-		case '@': parse_at();      break;
-		case '&': parse_amp();     break;
-		case '^': parse_carat();   break;
-		case '%': parse_pcnt();    break;
-		case '|': parse_vline();   break;
-		case '>': parse_greater(); break;
-		case '<': parse_less();    break;
-		case '[': parse_relayed(); break;
 	}
 
 	rx_text.clear();
@@ -640,14 +675,14 @@ void fsq::parse_pound(std::string relay)
 {
 	size_t p1 = NIT, p2 = NIT;
 	std::string fname = "";
-	bool named_file = false;
+	bool call_file = true;
 	p1 = rx_text.find('[');
 	if (p1 != NIT) {
 		p2 = rx_text.find(']', p1);
 		if (p2 != NIT) {
 			fname = rx_text.substr(p1 + 1, p2 - p1 - 1);
 			fname = fl_filename_name(fname.c_str());
-			named_file = true;
+			call_file = false;
 		} else p2 = 0;
 	} else p2 = 0;
 	if (fname.empty()) {
@@ -660,13 +695,18 @@ void fsq::parse_pound(std::string relay)
 
 	std::ofstream rxfile;
 	fname.insert(0, TempDir);
-	if (named_file) {
+	if (call_file) {
 		rxfile.open(fname.c_str(), ios::app);
 	} else {
 		rxfile.open(fname.c_str(), ios::out);
 	}
 	if (!rxfile) return;
-	rxfile << rx_text.substr(p2+1);
+	if (call_file && progdefaults.add_fsq_msg_dt) {
+		rxfile << "Received: " << zdate() << ", " << ztime() << "\n";
+		rxfile << rx_text.substr(p2+1) << "\n";
+	} else
+		rxfile << rx_text.substr(p2+1);
+
 	rxfile.close();
 
 	display_fsq_rx_text(toprint.append(rx_text).append("\n"), FTextBase::FSQ_DIR);
@@ -1119,7 +1159,6 @@ void fsq::recvpic(double smpl)
 int fsq::rx_process(const double *buf, int len)
 {
 	if (peak_hits != progdefaults.fsqhits) restart();
-//	if (fsq_frequency != progdefaults.fsq_frequency) restart();
 	if (movavg_size != progdefaults.fsq_movavg) restart();
 	if (speed != progdefaults.fsqbaud) restart();
 	if (heard_log_fname != progdefaults.fsq_heard_log ||
@@ -1161,9 +1200,10 @@ int fsq::rx_process(const double *buf, int len)
 						&rx_stream[SHIFT_SIZE],				// from
 						BLOCK_SIZE*sizeof(*rx_stream));	// # bytes
 				memset(fft_data, 0, sizeof(fft_data));
-				for (int i = 0; i < BLOCK_SIZE; i++)
-					fft_data[i].real() = fft_data[i].imag() =
-						rx_stream[i] * a_blackman[i];
+				for (int i = 0; i < BLOCK_SIZE; i++) {
+					double d = rx_stream[i] * a_blackman[i];
+					fft_data[i] = cmplx(d, d);
+				}
 				fft->ComplexFFT(fft_data);
 				process_tones();
 			}
@@ -1195,14 +1235,14 @@ void fsq::flush_buffer()
 void fsq::send_tone(int tone)
 {
 	double phaseincr;
-	double frequency;
+	double freq;
 
 	if (speed != progdefaults.fsqbaud) restart();
 
-	frequency = (basetone + tone * spacing) * samplerate / FSQ_SYMLEN;
+	freq = (tx_basetone + tone * spacing) * samplerate / FSQ_SYMLEN;
 	if (grpNoise->visible() && btnOffsetOn->value()==true)
-		frequency += ctrl_freq_offset->value();
-	phaseincr = 2.0 * M_PI * frequency / samplerate;
+		freq += ctrl_freq_offset->value();
+	phaseincr = 2.0 * M_PI * freq / samplerate;
 	prevtone = tone;
 
 	int send_symlen = symlen;
@@ -1375,6 +1415,7 @@ int fsq::tx_process()
 			put_echo_char(aborted[n]);
 		fsq_tx_image = false;
 		stopflag = false;
+		clear_xmt_arrays();
 		return -1;
 	}
 	send_char(c);
@@ -1393,6 +1434,13 @@ static vector<string> commands;
 #define NUMCOMMANDS 10
 static size_t next = 0;
 
+void  clear_xmt_arrays()
+{
+	commands.erase(commands.begin(), commands.begin());
+	tx_text_queue.clear();
+	fsq_tx_text->clear();
+}
+
 double fsq_xmtdelay() // in seconds
 {
 #define MIN_DELAY  50
@@ -1407,10 +1455,14 @@ double fsq_xmtdelay() // in seconds
 
 void fsq_repeat_last_command()
 {
+	using ::next;  // disambiguate from std::next
+	if (commands.empty()) return;
 	fsq_tx_text->clear();
 	fsq_tx_text->addstr(sz2utf8(commands[next].c_str()));
 	next++;
-	if (next == commands.size()) next = 0;
+	if (next == commands.size()) {
+		next = 0;
+	}
 }
 
 int get_fsq_tx_char(void)
@@ -1452,7 +1504,7 @@ void try_transmit(void *)
 	if (active_modem != fsq_modem) return;
 
 	if (!active_modem->fsq_squelch_open() && trx_state == STATE_RX) {
-		next = 0;
+		::next = 0;
 		fsq_que_clear();
 //LOG_WARN("%s", "start_tx()");
 		start_tx();
@@ -1652,6 +1704,7 @@ void sounder(void *)
 		Fl::repeat_timeout(10, sounder); // retry in 10 seconds
 		return;
 	}
+	sounder_tries = 10;
 	std::string xmtstr = FSQBOL;
 	xmtstr.append(active_modem->fsq_mycall()).append(":").append(FSQEOT);
 	int numsymbols = xmtstr.length();
@@ -1697,6 +1750,7 @@ void fsq::start_sounder(int interval)
 		case 1: sounder_secs = 60; break;   // 1 minute
 		case 2: sounder_secs = 600; break;  // 10 minutes
 		case 3: sounder_secs = 1800; break; // 30 minutes
+		case 4: sounder_secs = 3600; break; // 60 minutes
 		default: sounder_secs = 600;
 	}
 	REQ(fsq_start_sounder);
