@@ -46,10 +46,13 @@
 #include "smeter.h"
 #include "pwrmeter.h"
 #include "picture.h"
+#include "dropwin.h"
 
 extern fre_t seek_re;
 
-extern Fl_Double_Window *fl_digi_main;
+//extern Fl_Double_Window *fl_digi_main;
+extern dropwin			*fl_digi_main;
+
 extern Fl_Double_Window *scopeview;
 //extern Fl_Double_Window *opBrowserView;
 
@@ -57,6 +60,8 @@ extern Fl_Double_Window *dlgRecordLoader;
 
 extern bool first_use;
 
+extern bool		bMOREINFO;
+
 extern FTextRX			*ReceiveText;
 extern FTextTX			*TransmitText;
 extern pskBrowser		*mainViewer;
@@ -77,14 +82,17 @@ extern Fl_Counter2		*cntCW_WPM;
 extern Fl_Counter2		*cntTxLevel;
 extern Fl_Button		*MODEstatus;
 extern Fl_Slider2		*sldrSquelch;
-extern Progress		*pgrsSquelch;
+extern Progress			*pgrsSquelch;
 extern Smeter			*smeter;
-extern PWRmeter		*pwrmeter;
+extern PWRmeter 		*pwrmeter;
+extern Fl_Value_Slider2	*pwr_level;
+extern Fl_Group			*pwrlevel_grp;
 extern Fl_Button 		*btnMacro[];
 extern Fl_Button		*btnAltMacros1;
 extern Fl_Button		*btnAltMacros2;
-extern Fl_Group		*macroFrame1;
-extern Fl_Group		*macroFrame2;
+extern Fl_Button		*btnDockMacro[];
+extern Fl_Group			*macroFrame1;
+extern Fl_Group			*macroFrame2;
 extern Fl_Input2		*inpFreq;
 extern Fl_Input2		*inpTimeOff;
 extern Fl_Input2		*inpTimeOn;
@@ -152,6 +160,9 @@ extern void				write_fsqDebug(std::string s, int style = FTextBase::RECV);
 extern void				fsq_que_clear();
 extern void				write_fsq_que(std::string s);
 
+extern void start_tx_timer();
+extern void stop_tx_timer();
+
 extern void fsq_disableshift();
 extern void fsq_enableshift();
 extern void fsq_updateRxPic(unsigned char data, int pos);
@@ -204,30 +215,34 @@ extern void			display_fsq_mon_text(std::string text, int style = FTextBase::SKIP
 extern Fl_Group		*ifkp_group;
 extern Fl_Group		*ifkp_upper;
 extern Fl_Group		*ifkp_upper_left;
-extern FTextRX			*ifkp_rx_text;
+extern FTextRX		*ifkp_rx_text;
 extern Fl_Group		*ifkp_upper_right;
-extern Fl_Browser		*ifkp_heard;
+extern Fl_Browser	*ifkp_heard;
 extern Progress		*ifkp_s2n_progress;
 extern Fl_Group		*ifkp_lower;
-extern FTextTX			*ifkp_tx_text;
-extern picture			*ifkp_avatar;
-int						ifkp_load_avatar(std::string image_fname = "", int W=59, int H=74);
-extern					void ifkp_clear_avatar();
-extern					void ifkp_update_avatar(unsigned char data, int pos);
-extern					int ifkp_get_avatar_pixel(int pos, int color);
-extern					void cb_ifkp_send_avatar( Fl_Widget *w, void *);
+extern FTextTX		*ifkp_tx_text;
+extern picture		*ifkp_avatar;
+extern int			ifkp_load_avatar(std::string image_fname = "", int W=59, int H=74);
+extern void			ifkp_clear_avatar();
+extern void			ifkp_update_avatar(unsigned char data, int pos);
+extern int			ifkp_get_avatar_pixel(int pos, int color);
+extern void			cb_ifkp_send_avatar( Fl_Widget *w, void *);
 
 extern void			cb_ifkp_heard(Fl_Browser*, void*);
 
 extern void			enableSELCAL();
 
+extern unsigned char tux_img[];
+
 extern void			cbFSQQTC(Fl_Widget *w, void *d);
 extern void			cbFSQQTH(Fl_Widget *w, void *d);
+extern void			cbFSQCQ(Fl_Widget *w, void *d);
 extern void			cbMONITOR(Fl_Widget *w, void *d);
 extern void			cbSELCAL(Fl_Widget *w, void *d);
 extern void			cbFSQCALL(Fl_Widget *w, void *d);
 
 extern void			ifkp_showTxViewer(char C = 'T');
+extern void			ifkp_load_scaled_image(std::string);
 extern Fl_Double_Window	*ifkppicRxWin;
 extern Fl_Double_Window	*ifkppicTxWin;
 
@@ -257,6 +272,7 @@ extern Fl_Value_Slider2	*mvsquelch;
 extern Fl_Light_Button		*btnAFC;
 extern Fl_Light_Button		*btnSQL;
 extern Fl_Light_Button		*btnPSQL;
+extern Fl_Box				*rsid_status;
 extern Fl_Light_Button		*btnRSID;
 extern Fl_Light_Button		*btnTxRSID;
 extern Fl_Light_Button		*btnTune;
@@ -528,4 +544,17 @@ extern void log_callback(Fl_Input2 *);
 
 extern void set599();
 
+// thor images
+extern	void				thor_showTxViewer(char C = 'T');
+extern	Fl_Double_Window	*thorpicRxWin;
+extern	Fl_Double_Window	*thorpicTxWin;
+
+extern int			thor_load_avatar(std::string image_fname = "", int W=59, int H=74);
+extern void			thor_clear_avatar();
+extern void			thor_update_avatar(unsigned char data, int pos);
+extern int			thor_get_avatar_pixel(int pos, int color);
+extern void			cb_thor_send_avatar( Fl_Widget *w, void *);
+extern picture		*thor_avatar;
+extern void			thor_load_scaled_image(std::string fname);
+
 #endif
