@@ -150,9 +150,12 @@ public:
 	virtual void		send_color_image(std::string) {}
 	virtual void		send_Grey_image(std::string) {}
 
-	virtual void		ifkp_send_image(){}
+	virtual void		ifkp_send_image(std::string s = ""){}
 	virtual void		ifkp_send_avatar(){}
 
+	virtual void		thor_send_image(std::string s = ""){}
+	virtual void		thor_send_avatar(){}
+
 	void		set_stopflag(bool b) { stopflag = b;};
 	bool		get_stopflag() const { return stopflag; };
 
@@ -243,10 +246,9 @@ public:
 	int  ovhd_samples;
 
 // analysis mode
+	int  write_to_csv;
 	virtual void start_csv() {}
 	virtual void stop_csv() {}
-	virtual int is_csv() { return true;}
-	virtual double track_freq() { return 0;}
 
 // fsq mode
 	bool    fsq_tx_image;
@@ -320,7 +322,9 @@ extern modem *_8psk1000_modem;
 extern modem *_8psk1200_modem;
 extern modem *_8psk1333_modem;
 
+extern modem *_8psk125fl_modem;
 extern modem *_8psk125f_modem;
+extern modem *_8psk250fl_modem;
 extern modem *_8psk250f_modem;
 extern modem *_8psk500f_modem;
 extern modem *_8psk1000f_modem;
