@@ -52,6 +52,7 @@ enum {
 	XMLRPC_TID,
 	ARQ_TID,
 	ARQSOCKET_TID,
+	MACLOGGER_TID,
 	KISS_TID,
 	KISSSOCKET_TID,
 	FLMAIN_TID,
@@ -107,6 +108,7 @@ bool thread_in_list(int id, const int* list);
 // which will also interrupt blocking calls.  On woe32 we use
 // pthread_cancel and there is no good/sane way to interrupt.
 #ifndef __WOE32__
+#include <signal.h>
 #  define SET_THREAD_CANCEL()					\
 	do {							\
 		sigset_t usr2;					\
