@@ -150,6 +150,8 @@ void loadBrowser(Fl_Widget *widget) {
 	w->add(_("<QSY+:+/-n.nnn>\tincr/decr xcvr freq"));
 	w->add(_("<RIGMODE:mode>\tvalid xcvr mode"));
 	w->add(_("<FILWID:width>\tvalid xcvr filter width"));
+	w->add(_("<RIGLO:lowcut>\tvalid xcvr low cutoff filter"));
+	w->add(_("<RIGHI:hicut>\tvalid xcvr hi cutoff filter"));
 	w->add(_("<FOCUS>\trig freq has kbd focus"));
 
 	w->add(LINE_SEP);
@@ -308,9 +310,9 @@ void update_macro_button(int iMacro, const char *text, const char *name)
 
 	if (progdefaults.mbar_scheme > MACRO_SINGLE_BAR_MAX) {
 		if (iMacro < NUMMACKEYS) {
-			btnMacro[iMacro % NUMMACKEYS]->label( macros.name[iMacro].c_str() );
-			btnMacro[iMacro % NUMMACKEYS]->redraw_label();
-		} else {
+			btnMacro[iMacro]->label( macros.name[iMacro].c_str() );
+			btnMacro[iMacro]->redraw_label();
+		} else if ((iMacro / NUMMACKEYS) == altMacros) {
 			btnMacro[(iMacro % NUMMACKEYS) + NUMMACKEYS]->label( macros.name[iMacro].c_str() );
 			btnMacro[(iMacro % NUMMACKEYS) + NUMMACKEYS]->redraw_label();
 		}
@@ -318,7 +320,10 @@ void update_macro_button(int iMacro, const char *text, const char *name)
 		btnMacro[iMacro % NUMMACKEYS]->label( macros.name[iMacro].c_str() );
 		btnMacro[iMacro % NUMMACKEYS]->redraw_label();
 	}
-
+	if (progdefaults.dockable_macros) {
+		btnDockMacro[iMacro]->label(macros.name[iMacro].c_str());
+		btnDockMacro[iMacro]->redraw_label();
+	}
 	macros.changed = true;
 }
 
@@ -339,7 +344,7 @@ void cbInsertMacro(Fl_Widget *, void *)
 			_("Text file to insert"),
 			filters.c_str(),
 			HomeDir.c_str());
-		if (p) {
+		if (p && *p) {
 			text.insert(6, p);
 		} else
 			text = "";
@@ -349,7 +354,7 @@ void cbInsertMacro(Fl_Widget *, void *)
 			_("Test text file"),
 			filters.c_str(),
 			HomeDir.c_str());
-		if (p) {
+		if (p && *p) {
 			text.insert(10, p);
 		} else
 			text = "";
@@ -359,7 +364,7 @@ void cbInsertMacro(Fl_Widget *, void *)
 			_("MFSK image file"),
 			filters.c_str(),
 			PicsDir.c_str());
-		if (p) {
+		if (p && *p) {
 			text.insert(7, p);
 		} else
 			text = "";
@@ -369,7 +374,7 @@ void cbInsertMacro(Fl_Widget *, void *)
 			_("Change to Macro file"),
 			filters.c_str(),
 			MacrosDir.c_str());
-		if (p) {
+		if (p && *p) {
 			text.insert(8, p);
 		} else
 			text = "";
@@ -381,7 +386,7 @@ void cbInsertMacro(Fl_Widget *, void *)
 			_("Executable file to insert"),
 			filters.c_str(),
 			HomeDir.c_str());
-		if (p) {
+		if (p && *p) {
 			string exefile = p;
 			exefile.append("</EXEC>");
 			text.insert(6, exefile);
