@@ -1892,6 +1892,74 @@ static void pTxQueIMAGE(std::string &s, size_t &i, size_t endbracket)
 	s.replace(i, endbracket - i + 1, "^!");
 }
 
+static void doINSERTIMAGE(std::string s)
+{
+	if (s.length() > 0) {
+
+		bool Greyscale = false;
+		size_t p = string::npos;
+		string fname = s.substr(7);
+		p = fname.find(">");
+		fname.erase(p);
+		p = fname.find("G,");
+		if (p == string::npos) p = fname.find("g,");
+		if (p != string::npos) {
+			Greyscale = true;
+			fname.erase(p,2);
+		}
+		while (fname[0] == ' ') fname.erase(0,1);
+		if (s.empty()) return;
+
+		trx_mode md = active_modem->get_mode();
+		if ((md == MODE_MFSK16 || md == MODE_MFSK32 ||
+			 md == MODE_MFSK64 || md == MODE_MFSK128) &&
+			active_modem->get_cap() & modem::CAP_IMG) {
+				Greyscale ?
+					active_modem->send_Grey_image(fname) :
+					active_modem->send_color_image(fname);
+		}
+		else if (md == MODE_IFKP) {
+			ifkp_load_scaled_image(fname);
+		}
+		else if (md >= MODE_THOR_FIRST && md <= MODE_THOR_LAST)
+			thor_load_scaled_image(fname);
+	}
+	que_ok = true;
+}
+
+void TxQueINSERTIMAGE(std::string s)
+{
+	trx_mode active_mode = active_modem->get_mode();
+	if (! (active_mode == MODE_MFSK16 ||
+		   active_mode == MODE_MFSK32 ||
+		   active_mode == MODE_MFSK64 ||
+		   active_mode == MODE_MFSK128 ||
+		   active_mode == MODE_IFKP ||
+		   (active_mode >= MODE_THOR_FIRST && active_mode <= MODE_THOR_LAST) ) &&
+		   active_modem->get_cap() & modem::CAP_IMG)
+		return;
+
+	string scmd = "<IMAGE:>";
+	scmd.insert(7,s);
+
+	struct CMDS cmd = { scmd, doINSERTIMAGE };
+	push_txcmd(cmd);
+
+	string itext = s;
+	size_t p = itext.rfind("\\");
+	if (p == string::npos) p = itext.rfind("/");
+	if (p != string::npos) itext.erase(0, p+1);
+	p = itext.rfind(".");
+	if (p != string::npos) itext.erase(p);
+	itext.insert(0, "\nImage: ");
+	itext.append(" ^!");
+
+	if (active_mode == MODE_IFKP)
+		ifkp_tx_text->add_text(itext);
+	else
+		TransmitText->add_text(itext);
+}
+
 #include <float.h>
 #include "re.h"
 
@@ -2549,57 +2617,13 @@ static void pTxQueQSY(std::string &s, size_t &i, size_t endbracket)
 	s.replace(i, endbracket - i + 1, "^!");
 }
 
-float  waitFILWID = 0.0;
+float  wait_after_mode_change = 0.0;
 static string sFILWID;
 static void delayedFILWID(void *)
 {
 	qso_opBW->value(sFILWID.c_str());
 	cb_qso_opBW();
-	waitFILWID = 0.0;
-}
-
-static void pRIGMODE(std::string& s, size_t& i, size_t endbracket)
-{
-	if (within_exec) {
-		s.replace(i, endbracket - i + 1, "");
-		return;
-	}
-	std::string sMode = s.substr(i+9, endbracket - i - 9);
-	qso_opMODE->value(sMode.c_str());
-	cb_qso_opMODE();
-	s.replace(i, endbracket - i + 1, "");
-	if (s.find("FILWID") != string::npos)
-		waitFILWID = progdefaults.mbw;
-}
-
-static void doRIGMODE(std::string s)
-{
-	std::string sMode = s.substr(10, s.length() - 11);
-	qso_opMODE->value(sMode.c_str());
-	cb_qso_opMODE();
-	que_ok = true;
-}
-
-static void pTxQueRIGMODE(std::string &s, size_t &i, size_t endbracket)
-{
-	if (within_exec) {
-		s.replace(i, endbracket - i + 1, "");
-		return;
-	}
-	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGMODE };
-	push_txcmd(cmd);
-	s.replace(i, endbracket - i + 1, "^!");
-}
-
-static void pRxQueRIGMODE(std::string &s, size_t &i, size_t endbracket)
-{
-	if (within_exec) {
-		s.replace(i, endbracket - i + 1, "");
-		return;
-	}
-	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGMODE };
-	push_rxcmd(cmd);
-	s.replace(i, endbracket - i + 1, "");
+	wait_after_mode_change = 0.0;
 }
 
 static void pFILWID(std::string& s, size_t& i, size_t endbracket)
@@ -2609,10 +2633,8 @@ static void pFILWID(std::string& s, size_t& i, size_t endbracket)
 		return;
 	}
 	std::string sWidth = s.substr(i+8, endbracket - i - 8);
-//	qso_opBW->value(sWidth.c_str());
-//	cb_qso_opBW();
 	sFILWID = sWidth;
-	Fl::add_timeout(waitFILWID, delayedFILWID);
+	Fl::add_timeout(wait_after_mode_change, delayedFILWID);
 	s.replace(i, endbracket - i + 1, "");
 }
 
@@ -2646,6 +2668,166 @@ static void pRxQueFILWID(std::string &s, size_t &i, size_t endbracket)
 	s.replace(i, endbracket - i + 1, "");
 }
 
+static void pRIGMODE(std::string& s, size_t& i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	std::string sMode = s.substr(i+9, endbracket - i - 9);
+	qso_opMODE->value(sMode.c_str());
+	cb_qso_opMODE();
+	s.replace(i, endbracket - i + 1, "");
+	if ((s.find("FILWID") != string::npos) ||
+		(s.find("RIGLO") != string::npos) ||
+		(s.find("RIGHI") != string::npos) )
+		wait_after_mode_change = progdefaults.mbw;
+	else
+		wait_after_mode_change = 0;
+}
+
+static void doRIGMODE(std::string s)
+{
+	std::string sMode = s.substr(10, s.length() - 11);
+	qso_opMODE->value(sMode.c_str());
+	cb_qso_opMODE();
+	que_ok = true;
+}
+
+static void pTxQueRIGMODE(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGMODE };
+	push_txcmd(cmd);
+	s.replace(i, endbracket - i + 1, "^!");
+}
+
+static void pRxQueRIGMODE(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGMODE };
+	push_rxcmd(cmd);
+	s.replace(i, endbracket - i + 1, "");
+}
+
+static string sRIGLO;
+
+static void delayedRIGLO(void *)
+{
+	qso_opBW2->value(sRIGLO.c_str());
+	cb_qso_opBW2();
+	wait_after_mode_change = 0.0;
+}
+
+static void pRIGLO(std::string& s, size_t& i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	std::string sLO = s.substr(i+7, endbracket - i - 7);
+	sRIGLO = sLO;
+	if (wait_after_mode_change)
+		Fl::add_timeout(wait_after_mode_change, delayedRIGLO);
+	else {
+		qso_opBW2->value(sLO.c_str());
+		cb_qso_opBW2();
+	}
+	s.replace(i, endbracket - i + 1, "");
+}
+
+static void doRIGLO(std::string s)
+{
+	std::string sLO = s.substr(8, s.length() - 9);
+	qso_opBW2->value(sLO.c_str());
+	cb_qso_opBW2();
+	que_ok = true;
+}
+
+static void pTxQueRIGLO(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGLO };
+	push_txcmd(cmd);
+	s.replace(i, endbracket - i + 1, "^!");
+}
+
+static void pRxQueRIGLO(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGLO };
+	push_rxcmd(cmd);
+	s.replace(i, endbracket - i + 1, "");
+}
+
+static string sRIGHI;
+
+static void delayedRIGHI(void *)
+{
+	qso_opBW1->value(sRIGHI.c_str());
+	cb_qso_opBW1();
+	wait_after_mode_change = 0.0;
+}
+
+static void pRIGHI(std::string& s, size_t& i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	std::string sHI = s.substr(i+7, endbracket - i - 7);
+	sRIGHI = sHI;
+	if (wait_after_mode_change)
+		Fl::add_timeout(wait_after_mode_change, delayedRIGHI);
+	else {
+		qso_opBW1->value(sHI.c_str());
+		cb_qso_opBW1();
+	}
+	s.replace(i, endbracket - i + 1, "");
+}
+
+static void doRIGHI(std::string s)
+{
+	std::string sHI = s.substr(8, s.length() - 9);
+	qso_opBW1->value(sHI.c_str());
+	cb_qso_opBW1();
+	que_ok = true;
+}
+
+static void pTxQueRIGHI(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGHI };
+	push_txcmd(cmd);
+	s.replace(i, endbracket - i + 1, "^!");
+}
+
+static void pRxQueRIGHI(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRIGHI };
+	push_rxcmd(cmd);
+	s.replace(i, endbracket - i + 1, "");
+}
+
 static void pWX(std::string &s, size_t &i, size_t endbracket)
 {
 	string wx;
@@ -2668,21 +2850,82 @@ void set_macro_env(void)
 #ifndef __WOE32__
 		pSKEDH, FLDIGI_RX_IPC_KEY, FLDIGI_TX_IPC_KEY,
 #endif
-		FLDIGI_XMLRPC_ADDRESS, FLDIGI_XMLRPC_PORT,
-		FLDIGI_ARQ_ADDRESS, FLDIGI_ARQ_PORT,
+		FLDIGI_XMLRPC_ADDRESS,
+		FLDIGI_XMLRPC_PORT,
+		FLDIGI_ARQ_ADDRESS,
+		FLDIGI_ARQ_PORT,
 
-		FLDIGI_VERSION_ENVVAR, FLDIGI_PID, FLDIGI_CONFIG_DIR,
+		FLDIGI_VERSION_ENVVAR,
+		FLDIGI_PID,
+		FLDIGI_CONFIG_DIR,
 
-		FLDIGI_MY_CALL, FLDIGI_MY_NAME, FLDIGI_MY_LOCATOR,
+		FLDIGI_MY_CALL,
+		FLDIGI_MY_NAME,
+		FLDIGI_MY_LOCATOR,
 
-		FLDIGI_MODEM, FLDIGI_MODEM_LONG_NAME, FLDIGI_DIAL_FREQUENCY,
-		FLDIGI_AUDIO_FREQUENCY, FLDIGI_FREQUENCY,
+		FLDIGI_MODEM,
+		FLDIGI_MODEM_LONG_NAME,
+		FLDIGI_MODEM_ADIF_NAME,
+		FLDIGI_DIAL_FREQUENCY,
+		FLDIGI_AUDIO_FREQUENCY,
+		FLDIGI_FREQUENCY,
 
 		FLDIGI_MACRO_FILE,
+
 		FLDIGI_LOG_FILE,
-		FLDIGI_LOG_FREQUENCY, FLDIGI_LOG_TIME_ON, FLDIGI_LOG_TIME_OFF, FLDIGI_LOG_CALL, FLDIGI_LOG_NAME,
-		FLDIGI_LOG_RST_IN, FLDIGI_LOG_RST_OUT, FLDIGI_LOG_QTH, FLDIGI_LOG_LOCATOR,
-		FLDIGI_LOG_NOTES, FLDIGI_AZ, ENV_SIZE
+		FLDIGI_LOG_FREQUENCY,
+		FLDIGI_LOG_DATE,
+		FLDIGI_LOG_DATE_OFF,
+		FLDIGI_LOG_TIME_ON,
+		FLDIGI_LOG_TIME_OFF,
+		FLDIGI_LOG_CALL,
+		FLDIGI_LOG_NAME,
+		FLDIGI_LOG_RST_IN,
+		FLDIGI_LOG_RST_OUT,
+		FLDIGI_LOG_QTH,
+		FLDIGI_LOG_LOCATOR,
+		FLDIGI_LOG_NOTES,
+		FLDIGI_LOG_STATE,
+		FLDIGI_LOG_COUNTRY,
+		FLDIGI_LOG_SERNO_IN,
+		FLDIGI_LOG_SERNO_OUT,
+		FLDIGI_XCHG_IN,
+		FLDIGI_XCGH_OUT,
+		FLDIGI_VE_PROV,
+		FLDIGI_AZ,
+
+		FLDIGI_LOGBOOK_CALL,
+		FLDIGI_LOGBOOK_NAME,
+		FLDIGI_LOGBOOK_DATE,
+		FLDIGI_LOGBOOK_TIME_ON,
+		FLDIGI_LOGBOOK_DATE_OFF,
+		FLDIGI_LOGBOOK_TIME_OFF,
+		FLDIGI_LOGBOOK_RST_IN,
+		FLDIGI_LOGBOOK_RST_OUT,
+		FLDIGI_LOGBOOK_FREQUENCY,
+		FLDIGI_LOGBOOK_MODE,
+		FLDIGI_LOGBOOK_STATE,
+		FLDIGI_LOGBOOK_VE_PROV,
+		FLDIGI_LOGBOOK_COUNTRY,
+		FLDIGI_LOGBOOK_SERNO_IN,
+		FLDIGI_LOGBOOK_SERNO_OUT,
+		FLDIGI_LOGBOOK_XCHG_IN,
+		FLDIGI_LOGBOOK_XCHG_OUT,
+		FLDIGI_LOGBOOK_QTH,
+		FLDIGI_LOGBOOK_LOCATOR,
+		FLDIGI_LOGBOOK_QSL_R,
+		FLDIGI_LOGBOOK_QSL_S,
+		FLDIGI_LOGBOOK_NOTES,
+		FLDIGI_LOGBOOK_TX_PWR,
+		FLDIGI_LOGBOOK_COUNTY,
+		FLDIGI_LOGBOOK_IOTA,
+		FLDIGI_LOGBOOK_DXCC,
+		FLDIGI_LOGBOOK_QSL_VIA,
+		FLDIGI_LOGBOOK_CONTINENT,
+		FLDIGI_LOGBOOK_CQZ,
+		FLDIGI_LOGBOOK_ITUZ,
+
+		ENV_SIZE
 	};
 
 	struct {
@@ -2709,6 +2952,8 @@ void set_macro_env(void)
 
 		{ "FLDIGI_MODEM", mode_info[active_modem->get_mode()].sname },
 		{ "FLDIGI_MODEM_LONG_NAME", mode_info[active_modem->get_mode()].name },
+		{ "FLDIGI_MODEM_ADIF_NAME", mode_info[active_modem->get_mode()].adif_name },
+
 		{ "FLDIGI_DIAL_FREQUENCY", "" },
 		{ "FLDIGI_AUDIO_FREQUENCY", "" },
 		{ "FLDIGI_FREQUENCY", "" },
@@ -2717,7 +2962,10 @@ void set_macro_env(void)
 		{ "FLDIGI_MACRO_FILE", progStatus.LastMacroFile.c_str() },
 
 		{ "FLDIGI_LOG_FILE", progdefaults.logbookfilename.c_str() },
+
 		{ "FLDIGI_LOG_FREQUENCY", inpFreq->value() },
+		{ "FLDIGI_LOG_DATE", inpDate_log->value() },
+		{ "FLDIGI_LOG_DATE_OFF", inpDateOff_log->value() },
 		{ "FLDIGI_LOG_TIME_ON", inpTimeOn->value() },
 		{ "FLDIGI_LOG_TIME_OFF", inpTimeOff->value() },
 		{ "FLDIGI_LOG_CALL", inpCall->value() },
@@ -2727,7 +2975,46 @@ void set_macro_env(void)
 		{ "FLDIGI_LOG_QTH", inpQth->value() },
 		{ "FLDIGI_LOG_LOCATOR", inpLoc->value() },
 		{ "FLDIGI_LOG_NOTES", inpNotes->value() },
-		{ "FLDIGI_AZ", inpAZ->value() }
+		{ "FLDIGI_LOG_STATE", inpState->value() },
+		{ "FLDIGI_LOG_COUNTRY", inpCountry->value() },
+		{ "FLDIGI_LOG_SERNO_IN", inpSerNo->value() },
+		{ "FLDIGI_LOG_SERNO_OUT", outSerNo->value() },
+		{ "FLDIGI_XCHG_IN", inpXchgIn->value() },
+		{ "FLDIGI_XCHG_OUT", inpSend1->value() },
+		{ "FLDIGI_VE_PROV", inpVEprov->value() },
+		{ "FLDIGI_AZ", inpAZ->value() },
+
+		{ "FLDIGI_LOGBOOK_CALL", inpCall_log->value() },
+		{ "FLDIGI_LOGBOOK_NAME", inpName_log->value () },
+		{ "FLDIGI_LOGBOOK_DATE", inpDate_log->value() },
+		{ "FLDIGI_LOGBOOK_TIME_ON", inpTimeOn_log->value() },
+		{ "FLDIGI_LOGBOOK_DATE_OFF", inpDateOff_log->value() },
+		{ "FLDIGI_LOGBOOK_TIME_OFF", inpTimeOff_log->value() },
+		{ "FLDIGI_LOGBOOK_RST_IN", inpRstR_log->value() },
+		{ "FLDIGI_LOGBOOK_RST_OUT", inpRstS_log->value() },
+		{ "FLDIGI_LOGBOOK_FREQUENCY", inpFreq_log->value() },
+		{ "FLDIGI_LOGBOOK_MODE", inpMode_log->value() },
+		{ "FLDIGI_LOGBOOK_STATE", inpState_log->value() },
+		{ "FLDIGI_LOGBOOK_VE_PROV", inpVE_Prov_log->value() },
+		{ "FLDIGI_LOGBOOK_COUNTRY", inpCountry_log->value() },
+		{ "FLDIGI_LOGBOOK_SERNO_IN", inpSerNoIn_log->value() },
+		{ "FLDIGI_LOGBOOK_SERNO_OUT", inpSerNoOut_log->value() },
+		{ "FLDIGI_LOGBOOK_XCHG_IN", inpXchgIn_log->value() },
+		{ "FLDIGI_LOGBOOK_XCHG_OUT", inpMyXchg_log->value() },
+		{ "FLDIGI_LOGBOOK_QTH", inpQth_log->value() },
+		{ "FLDIGI_LOGBOOK_LOCATOR", inpLoc_log->value() },
+		{ "FLDIGI_LOGBOOK_QSL_R", inpQSLrcvddate_log->value() },
+		{ "FLDIGI_LOGBOOK_QSL_S", inpQSLsentdate_log->value() },
+		{ "FLDIGI_LOGBOOK_NOTES", inpNotes_log->value() },
+		{ "FLDIGI_LOGBOOK_TX_PWR", inpTX_pwr_log->value() },
+		{ "FLDIGI_LOGBOOK_COUNTY", inpCNTY_log->value() },
+		{ "FLDIGI_LOGBOOK_IOTA", inpIOTA_log->value() },
+		{ "FLDIGI_LOGBOOK_DXCC", inpDXCC_log->value() },
+		{ "FLDIGI_LOGBOOK_QSL_VIA", inpQSL_VIA_log->value() },
+		{ "FLDIGI_LOGBOOK_CONTINENT", inpCONT_log->value() },
+		{ "FLDIGI_LOGBOOK_CQZ", inpCQZ_log->value() },
+		{ "FLDIGI_LOGBOOK_ITUZ", inpITUZ_log->value() }
+
 	};
 
 #ifndef __WOE32__
@@ -2772,8 +3059,13 @@ void set_macro_env(void)
 	unsetenv("MALLOC_PERTURB_");
 #endif
 
-	for (size_t j = 0; j < ENV_SIZE; j++)
-		setenv(env[j].var, env[j].val, 1);
+	string temp;
+	size_t pch;
+	for (size_t j = 0; j < ENV_SIZE; j++) {
+		temp = env[j].val;
+		while ((pch = temp.find("\n")) != string::npos) temp[pch] = ';';
+		setenv(env[j].var, temp.c_str(), 1);
+	}
 
 	string path = getenv("PATH");
 	string mypath = ScriptsDir;
@@ -3085,21 +3377,22 @@ bool queue_must_rx()
 // occurs immediately after the ^r execution
 // AND after TX_STATE returns to Rx
 // ^r is the control string substitute for the <RX> macro tag
-void Rx_queue_execute()
+int time_out = 400;
+void Rx_queue_execution(void *)
 {
-	if (Rx_cmds.empty()) return;
-
-	int time_out = 100; // force return after ten seconds
-	while (trx_state != STATE_RX && time_out) {
-		time_out--;
-		Fl::awake();
-		MilliSleep(100);
-	}
-	if (!time_out) {
-		while (!Rx_cmds.empty()) Rx_cmds.pop();
+	if (trx_state != STATE_RX) {
+		if (time_out-- == 0) {
+			while (!Rx_cmds.empty()) Rx_cmds.pop();
+			LOG_ERROR("%s", "failed");
+			time_out = 200;
+			return;
+		}
+		Fl::repeat_timeout( .050, Rx_queue_execution );
 		return;
 	}
+	LOG_INFO("action delayed by %4.2f seconds", (400 - time_out)*.050);
 
+	time_out = 400;
 	CMDS cmd;
 	while (!Rx_cmds.empty()) {
 		cmd = Rx_cmds.front();
@@ -3109,11 +3402,18 @@ void Rx_queue_execute()
 		cmd.cmd.erase(0,2);
 		cmd.cmd.insert(0,"<!");
 		cmd.fp(cmd.cmd);
+		Fl::awake();
 		if (macro_rx_wait) return;
 	}
 	return;
 }
 
+void Rx_queue_execute()
+{
+	if (Rx_cmds.empty()) return;
+	Fl::add_timeout(0, Rx_queue_execution);
+}
+
 void rx_que_continue(void *)
 {
 	macro_rx_wait = false;
@@ -3222,6 +3522,8 @@ static const MTAGS mtags[] = {
 {"<QSYFM>",		pQSYFM},
 {"<RIGMODE:",	pRIGMODE},
 {"<FILWID:",	pFILWID},
+{"<RIGHI:",     pRIGHI},
+{"<RIGLO:",     pRIGLO},
 {"<MAPIT:",		pMAPIT},
 {"<MAPIT>",		pMAPIT},
 {"<REPEAT>",	pREPEAT},
@@ -3247,6 +3549,8 @@ static const MTAGS mtags[] = {
 	{"<!MODEM:",	pTxQueMODEM},
 	{"<!RIGMODE:",	pTxQueRIGMODE},
 	{"<!FILWID:",	pTxQueFILWID},
+    {"<!RIGHI:",    pTxQueRIGHI},
+    {"<!RIGLO:",    pTxQueRIGLO},
 	{"<!TXATTEN:",	pTxQueTXATTEN},
 	{"<!RIGCAT:",	pTxQueRIGCAT},
 // Rx After action
@@ -3256,6 +3560,8 @@ static const MTAGS mtags[] = {
 	{"<@GOHOME>",	pRxQueGOHOME},
 	{"<@RIGMODE:",	pRxQueRIGMODE},
 	{"<@FILWID:",	pRxQueFILWID},
+    {"<@RIGHI:",    pRxQueRIGHI},
+    {"<@RIGLO:",    pRxQueRIGLO},
 	{"<@TXRSID:",	pRxQueTXRSID},
 	{"<@WAIT:",     pRxQueWAIT},
 
@@ -3373,10 +3679,9 @@ void MACROTEXT::openMacroFile()
 								 _("Open macro file"),
 								 _("Fldigi macro definition file\t*.{mdf}"),
 								 deffilename.c_str());
-	if (p) {
+	if (p && *p) {
 		loadMacros(p);
 		progStatus.LastMacroFile = p;
-//	}
 		showMacroSet();
 		if (progdefaults.DisplayMacroFilename) {
 			string Macroset;
@@ -3415,12 +3720,15 @@ void MACROTEXT::saveMacroFile()
 								 _("Save macro file"),
 								 _("Fldigi macro definition file\t*.{mdf}"),
 								 deffilename.c_str());
-	if (p) {
-		string sp = p;
-		if (sp.rfind(".mdf") == string::npos) sp.append(".mdf");
-		saveMacros(sp.c_str());
-		progStatus.LastMacroFile = sp;
-	}
+	if (!p) return;
+	if (!*p) return;
+
+	string sp = p;
+	if (sp.empty()) return;
+	if (sp.rfind(".mdf") == string::npos) sp.append(".mdf");
+	saveMacros(sp.c_str());
+	progStatus.LastMacroFile = sp;
+
 }
 
 void MACROTEXT::savecurrentMACROS(std::string &s, size_t &i, size_t endbracket)
