@@ -159,8 +159,8 @@ void SoundBase::get_file_params(const char* def_fname, const char** fname, int*
 		*fname = FSEL::select(_("Audio file"), filters.c_str(), def_fname, &fsel);
 	else
 		*fname = FSEL::saveas(_("Audio file"), filters.c_str(), def_fname, &fsel);
-	if (!*fname)
-		return;
+	if (!*fname) return;
+	if (!**fname) return;
 
 	if (fsel >= nfilt) // "Default" save-as type on OS X
 		fsel = 0;
@@ -1602,6 +1602,8 @@ void SoundPort::init_stream(unsigned dir)
 				else
 						sd[1].params.suggestedLatency = (*sd[dir].idev)->defaultHighOutputLatency;
 		sd[1].params.hostApiSpecificStreamInfo = NULL;
+		if (max_channels < 2)
+			sd[1].params.channelCount = max_channels;
 	}
 
 	const vector<double>& rates = supported_rates[dir][(*sd[dir].idev)->name];
